/*
 * This file is a part of CMSLU -- Content Management System like Unix
 * and is not publicly distributed
 * 
 * Copyright (c) 2008-2009, Tomasz Sowa
 * All rights reserved.
 * 
 */
 
#ifndef headerfilecmslutemplatestemplates
#define headerfilecmslutemplatestemplates

#include <iomanip>
#include <set>

#include "ezc.h"
#include "patterncacher.h"



namespace TemplatesFunctions
{
	using Ezc::Info;

	extern PatternCacher pattern_cacher;
	extern Ezc::Functions functions;
	extern Ezc::Pattern pat_item_info;
	extern Ezc::Pattern pat_item_tab_info;
	extern Ezc::Pattern pat_dir_last_info;

	
	
	/*
		sys
	*/
	void sys_ver_major(Info & i);
	void sys_ver_minor(Info & i);
	void sys_ver_revision(Info & i);


	/*
		doc
	*/
	void doc_language(Info & i);
	void doc_title(Info & i);
	void doc_charset(Info & i);
	void doc_base_url(Info & i);
	void doc_base_url_static(Info & i);
	void doc_base_url_static_auth(Info & i);
	void doc_current_url(Info & i);
	void doc_is_error(Info & i);
	void doc_status(Info & i);


	/*
		item
	*/
	void item_is(Info & i);
	void item_id(Info & i);
	void item_subject(Info & i);
	void item_subject_noescape(Info & i);
	void item_content(Info & i);
	void item_content_noescape(Info & i);
	void item_content_type_is(Info & i);
	void item_print_content(std::ostringstream & out, const std::string & content, Item::ContentType content_type);
	void item_print_content(Info & i);
	void item_privileges(Info & i);
	void item_dir(Info & i);
	void item_url(Info & i);
	void item_link(Info & i);
	void item_link_static_auth(Info & i);
	void item_static_auth_is_none(Info & i);
	void item_static_auth_is_image(Info & i);
	void item_static_auth_is_other(Info & i);
	void item_can_read(Info & i);
	void item_can_write(Info & i);
	void item_info(Info & i);
	void item_user(Info & i);
	void item_date_creation(Info & i);
	void item_date_modification(Info & i);
	void item_dates_equal(Info & i);
	void item_run(Info & i);
	void item_guest_name(Info & i);

	void item_old_id(Info & i);
	void item_old_subject(Info & i);
	void item_old_subject_noescape(Info & i);
	void item_old_content(Info & i);
	void item_old_content_noescape(Info & i);
	void item_old_privileges(Info & i);
	void item_old_dir(Info & i);
	void item_old_url(Info & i);
	void item_old_link(Info & i);

	void item_tab(Info & i);
	void item_tab_id(Info & i);
	void item_tab_subject(Info & i);
	void item_tab_subject_noescape(Info & i);
	void item_tab_content(Info & i);
	void item_tab_content_noescape(Info & i);
	void item_tab_print_content(Info & i);
	void item_tab_privileges(Info & i);
	void item_tab_dir(Info & i);
	void item_tab_url(Info & i);
	void item_tab_link(Info & i);
	void item_tab_can_read(Info & i);
	void item_tab_info(Info & i);
	void item_tab_user(Info & i);
	void item_tab_date_creation(Info & i);
	void item_tab_date_modification(Info & i);
	void item_tab_dates_equal(Info & i);
	void item_tab_run(Info & i);
	
	
	/*
		dir
	*/
	void dir(Info & i);
	void dir_can_read_exec(Info & i);
	void dir_can_write(Info & i);
	void dir_can_remove(Info & i);
	void dir_can_use_emacs(Info & i);
	void dir_can_use_mkdir(Info & i);
	
	void dir_childs_tab(Info & i);
	void dir_childs_tab_url(Info & i);

	void dir_tab(Info & i);
	void dir_tab_url(Info & i);
	void dir_tab_link(Info & i);

	void dir_last_default_item_dir(Info &);
	void dir_last_default_item_url(Info & i);
	void dir_last_subject(Info & i);
	void dir_last_info(Info & i);
	void dir_last_user(Info & i);
	void dir_last_date_creation(Info & i);
	void dir_last_date_modification(Info & i);
	void dir_last_dates_equal(Info & i);
	
	void dir_old(Info & i);


	/*
		user
	*/
	void user_name(Info & i);
	void user_logged(Info & i);
	void user_super_user(Info & i);
	void user_can_use_html(Info & i);
	void user_can_use_bbcode(Info & i);
	void user_can_use_raw(Info & i);
	
	/*
		privileges
	*/
	void priv_user_tab(Info & i);
	void priv_user_tab_name(Info & i);
	void priv_user_tab_isdefault(Info & i);
	
	void priv_group_tab(Info & i);
	void priv_group_tab_name(Info & i);
	void priv_group_tab_isdefault(Info & i);
	
	void priv_privileges(Info & i);
	
	/*
		done
	*/
	void done_is_error(Info & i);
	void done_status(Info & i);
	void done_status_no_item(Info & i);
	void done_status_incorrect_dir(Info & i);
	void done_status_incorrect_rebus(Info & i);
	void done_status_spam(Info & i);

	void done_added_item(Info & i);
	void done_edited_item(Info & i);
	void done_deleted_item(Info & i);
	void done_privileged_item(Info & i);

	void done_added_dir(Info & i);
	void done_deleted_dir(Info & i);
	void done_defaulted_dir(Info & i);

	void done_loggedout(Info & i);
	void done_reloaded_templates(Info & i);

	/*
		who
	*/
	void who_tab(Info & i);
	void who_tab_lp(Info & i);
	void who_tab_user(Info & i);
	void who_tab_time(Info & i);
	void who_tab_last_time(Info & i);


	/*
		last
	*/
	void last_tab(Info & i);
	void last_tab_name(Info & i);
	void last_tab_ip(Info & i);
	void last_tab_start(Info & i);
	void last_tab_end(Info & i);


	/*
		thread
	*/
	void thread_is(Info & i);
	void thread_tab(Info & i);
	void thread_tab_url(Info & i);
	void thread_tab_subject(Info & i);
	void thread_tab_author(Info & i);
	void thread_tab_answers(Info & i);
	void thread_tab_last_item_date_modification(Info & i);
	void thread_tab_last_item_user(Info & i);
	void thread_can_create(Info & i);
	
	
	/*
		mount
	*/
	void mount_param_withheader(Info & i);
	void mount_param_withinfo(Info & i);
	void mount_param_thread_with_header(Info & i);
	void mount_param_thread_with_info(Info & i);
	void mount_is_thread(Info & i);
	void mount_is_cms(Info & i);

	
	/*
		rebus
	*/
	void rebus_question(Info & i);


} // namespace TemplatesFunctions




class Templates
{
public:

	void ReadTemplates();
	void CreateFunctions();
	void Generate();
	void GenerateRunRaw();

};



#endif
